ITemplateRenderer class abstract

Interface for template renderers.

All templates implement this interface, providing a uniform contract for rendering template files from a given context. This replaces the inconsistent static method / instance method mix in the old templates.

Implementation Guidelines:

  • Templates MUST be stateless - all inputs come from TemplateContext.
  • Templates SHOULD use SharedComponents for common code patterns.
  • Templates MUST return deterministic output for the same input.
Implementers

Constructors

ITemplateRenderer()

Properties

description String
Short description of what this template generates.
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
A human-readable name for this template (e.g., 'Provider Mobile').
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(TemplateContext context) List<GeneratedFile>
Renders all files for this template given the context.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited